@@ -33,7 +33,23 @@ class SelectionDialog(Pmw.Dialog):
 	self._list.pack(side='top', expand='true', fill='both',
 		padx = self['borderx'], pady = self['bordery'])
 
+        if not kw.has_key('activatecommand'):
+            # Whenever this dialog is activated, set the focus to the
+            # ScrolledListBox's listbox widget.
+            listbox = self.component('listbox')
+            self.configure(activatecommand = listbox.focus_set)
+
 	# Check keywords and initialise options.
-	self.initialiseoptions(SelectionDialog)
+	self.initialiseoptions()
+
+    # Need to explicitly forward this to override the stupid
+    # (grid_)size method inherited from Tkinter.Toplevel.Grid.
+    def size(self):
+	return self.component('listbox').size()
+
+    # Need to explicitly forward this to override the stupid
+    # (grid_)bbox method inherited from Tkinter.Toplevel.Grid.
+    def bbox(self, index):
+	return self.component('listbox').size(index)
 
 Pmw.forwardmethods(SelectionDialog, Pmw.ScrolledListBox, '_list')
